Module models

Module models 

Structs

Addr
address value
AddrEnabled
whether this address is enabled
AddrIndex
address identifier 0=all call, 1-3=sub addrs
AddrInfo
ApiError
Some error text
BadRequest
BusId
A valid bus ID as returned by i2c_bus_list
Config
Current
current value
Error
Whether there are any LED errors
Freq
frequency multipier, 0-255 inclusive
LedErrors
LedIndex
LED number
LedInfo
LedInfoArray
Offset
offset value, number of (125ns) clock cycles between on times of consecutive LEDs
OpError
OverTemp
Whether there is an over-temperature error
Pwm
PWM value, 0-255 inclusive
Sleep
whether sleep is enabled (oscillator not running when sleep is enabled, and it takes >= 500us to bring the device out of sleep)
Yaml
A YAML file

Enums

Group
whether config pwm/freq values control dimming or blinking Enumeration of values. Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)] which helps with FFI.
LedError
LED error Enumeration of values. Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)] which helps with FFI.
LedState
LED state Enumeration of values. Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)] which helps with FFI.
OutputChange
whether output changes on I2C STOP or ACK Enumeration of values. Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)] which helps with FFI.