whether config pwm/freq values control dimming or blinking
Enumeration of values.
Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)]
which helps with FFI.
whether output changes on I2C STOP or ACK
Enumeration of values.
Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)]
which helps with FFI.